@@ -18,9 +18,18 @@
 #ifndef ANDROID_DEFAULT
 # define ANDROID_DEFAULT 0
 #endif
+#ifndef TARGET_DEFAULT_ISA_SPEC
+# define TARGET_DEFAULT_ISA_SPEC ISA_SPEC_CLASS_2P2
+#endif
 #ifndef TARGET_RISCV_ATTRIBUTE
 # define TARGET_RISCV_ATTRIBUTE 0
 #endif
+#ifndef TARGET_RISCV_DEFAULT_ARCH
+# define TARGET_RISCV_DEFAULT_ARCH rv64gc
+#endif
+#ifndef TARGET_RISCV_DEFAULT_ABI
+# define TARGET_RISCV_DEFAULT_ABI lp64d
+#endif
 #ifdef IN_GCC
 # include "options.h"
 # include "insn-constants.h"
